import Vue from 'vue'
import Router from 'vue-router'
import NProgress from 'nprogress'

Vue.use(Router)

const router = new Router({
  routes: [{
    path: '/login',
    name: 'Login',
    component: () => import(`@/views/login`),
    meta: {title: '登录', skipAuth: true}
  }, {
    path: '/logout',
    name: 'Logout',
    component: () => import(`@/views/logout`),
    meta: {title: '退出登录'}
  }, {
    path: '/403',
    name: '403',
    component: () => import(`@/views/exception/403`),
    meta: {title: '403', skipAuth: true}
  }, {
    path: '/',
    redirect: '/news'
  }, {
    path: '/news',
    component: () => import(`@/views/main`),
    children: [{
      path: '/news',
      name: 'News',
      component: () => import(`@/views/news/list`),
      meta: {title: '新闻列表'}
    }, {
      path: '/news/edit',
      name: 'NewsEdit',
      component: () => import(`@/views/news/edit`),
      meta: {title: '修改新闻列表'}
    }]
  }, {
    path: '/courseIntroduce',
    component: () => import(`@/views/main`),
    children: [{
      path: '/courseIntroduce',
      name: 'CourseIntroduce',
      component: () => import(`@/views/courseIntroduce/list`),
      meta: {title: '课程介绍'}
    }, {
      path: '/courseIntroduce/edit',
      name: 'CourseIntroduceEdit',
      component: () => import(`@/views/courseIntroduce/edit`),
      meta: {title: '修改课程介绍'}
    }]
  }, {
    path: '/vrPanorama',
    component: () => import(`@/views/main`),
    children: [{
      path: '/vrPanorama',
      name: 'vrPanorama',
      component: () => import(`@/views/vr-panorama/list`),
      meta: {title: 'VR全景图'}
    }, {
      path: '/vrPanorama/edit',
      name: 'vrPanoramaEdit',
      component: () => import(`@/views/vr-panorama/edit`),
      meta: {title: '修改VR全景图'}
    }]
  }, {
    path: '/banner',
    component: () => import(`@/views/main`),
    children: [{
      path: '/banner',
      name: 'Banner',
      component: () => import(`@/views/banner/list`),
      meta: {title: 'Banner管理'}
    }, {
      path: '/banner/edit',
      name: 'BannerEdit',
      component: () => import(`@/views/banner/edit`),
      meta: {title: 'Banner管理-修改'}
    }, {
      path: '/3Dmodel',
      name: '3Dmodel',
      component: () => import(`@/views/3Dmodel/list`),
      meta: {title: '在线3D模型'}
    }, {
      path: '/3Dmodel/edit',
      name: '3DmodelEdit',
      component: () => import(`@/views/3Dmodel/edit`),
      meta: {title: '在线3D模型-修改'}
    }]
  }, {
      path: '/material',
      component: () => import(`@/views/main`),
      children: [{
        path: '/material',
        name: 'Material',
        component: () => import(`@/views/material/list`),
        meta: {title: '素材管理'}
      }]
  }
  ]
})

router.beforeEach((to, from, next) => {
  if (to.meta.skipAuth) {
    next()
  } else {
    if (to.query.token === null | to.query.token === '' | to.query.token === undefined) {
      if (localStorage.getItem('token') === null | localStorage.getItem('token') === '') {
        var cookies = document.cookie.split('; ')
        for (var arr of cookies) {
          var _cookies = arr.split('=')
          if (_cookies[0] === 'token') {
            if (_cookies[1] !== null && _cookies[1] !== '' && _cookies[1] !== undefined) {
              next()
            }
          }
        }
        next({name: '403', query: {redirect_url: window.location.href}})
      } else {
        if (to.matched.length === 0) { // 匹配前往的路由不存在
          from.name ? next({name: from.name}) : next('/error') // 判断此跳转路由的来源路由是否存在，存在的情况跳转到来源路由，否则跳转到404页面
        } else {
          next()
        }
      }
    } else {
      localStorage.setItem('token', to.query.token)
      if (to.matched.length === 0) { // 匹配前往的路由不存在
        from.name ? next({name: from.name}) : next('/error') // 判断此跳转路由的来源路由是否存在，存在的情况跳转到来源路由，否则跳转到404页面
      } else {
        next()
      }
    }
  }
  NProgress.start() // 每次切换页面时，调用进度条
})

router.afterEach(() => {
  NProgress.done() // 在即将进入新的页面组件前，关闭掉进度条
})

export default router
