import {Message} from 'element-ui'
import NProgress from 'nprogress'
import axios from 'axios'
// import router from '../router'

axios.defaults.baseURL = process.env.HOME_URL
axios.defaults.timeout = 30 * 1000 // 设置接口响应时间
// let loginUrl = '/login'

/**
 * 功能描述：Http Request 拦截器
 */
axios.interceptors.request.use((config) => {
  NProgress.start() // 展示进度条

  config.headers.common['authorization'] = 'Bearer ' + localStorage.getItem('token') // todo 设置真实token
  config.headers.common['Content-Type'] = 'application/json;charset=UTF-8'

  return config
}, (error) => { // 请求错误时做些事(接口错误、超时等)
  NProgress.done() // 隐藏进度条
  Message.error(`请求参数错误`, 10)

  /* 1.判断请求超时 */
  if (error.code === 'ECONNABORTED' && error.message.indexOf('timeout') !== -1) {
    // return service.request(originalRequest);//例如再重复请求一次
  }

  /* 2.需要重定向到错误页面 */
  if (error.response) {
    // error =errorInfo.data//页面那边catch的时候就能拿到详细的错误信息,看最下边的Promise.reject
    // router.push({
    //   path: `/error/${errorInfo.status}`// 404 403 500 ... 等
    // })
  }

  return Promise.reject(error) // 在调用的那边可以拿到(catch)你想返回的错误信息
})

/**
 * 功能描述：Http Response 拦截器
 */
axios.interceptors.response.use((res) => {
  NProgress.done() // 隐藏进度条
  let isTips = res.config.showMessage === undefined || res.config.showMessage === true
  let data = res.data
  /* 根据返回的code值来做不同的处理（和后端约定） */
  switch (data.errorCode) {
    case 0:
    case 200:
      return Promise.resolve(data)
    default:
      isTips && Message.error(`服务器返回异常：${data.errorMessage}`, 10)
      return Promise.reject(res)
  }
}, (error) => {
  Message.error(`服务器返回异常：${error}`, 10)

  if (error && error.response) {
    switch (error.response.status) {
      case 400:
        break
      case 403:
        window.location.href = `#/403`
        break
      default:
        break
    }
  }

  return Promise.reject(error)
})

export default {
  get (url, data = {}) {
    return new Promise((resolve, reject) => {
      axios.get(url, data).then(response => {
        resolve(response)
      }).catch(err => {
        reject(err)
      })
    })
  },
  delete (url, data = {}) {
    return new Promise((resolve, reject) => {
      axios.delete(url, data).then(response => {
        resolve(response)
      }).catch(err => {
        reject(err)
      })
    })
  },
  post (url, data = {}) {
    return new Promise((resolve, reject) => {
      axios.post(url, data).then(response => {
        resolve(response)
      }, err => {
        reject(err)
      })
    })
  },
  put (url, data = {}) {
    return new Promise((resolve, reject) => {
      axios.put(url, data).then(response => {
        resolve(response)
      }, err => {
        reject(err)
      })
    })
  },
  patch (url, data = {}) {
    return new Promise((resolve, reject) => {
      axios.patch(url, data).then(response => {
        resolve(response)
      }, err => {
        reject(err)
      })
    })
  }
}
